openlp-core team mailing list archive
-
openlp-core team
-
Mailing list archive
-
Message #26205
[Merge] lp:~alisonken1/openlp/song-select-import-test-fix into lp:openlp
Ken Roberts has proposed merging lp:~alisonken1/openlp/song-select-import-test-fix into lp:openlp.
Requested reviews:
Tim Bentley (trb143)
For more details, see:
https://code.launchpad.net/~alisonken1/openlp/song-select-import-test-fix/+merge/250233
Fix duplicate test names in songselect test
lp:~alisonken1/openlp/song-select-import-test-fix (revision 2503)
[SUCCESS] http://ci.openlp.org/job/Branch-01-Pull/957/
[SUCCESS] http://ci.openlp.org/job/Branch-02-Functional-Tests/883/
[SUCCESS] http://ci.openlp.org/job/Branch-03-Interface-Tests/827/
[SUCCESS] http://ci.openlp.org/job/Branch-04a-Windows_Functional_Tests/719/
[SUCCESS] http://ci.openlp.org/job/Branch-04b-Windows_Interface_Tests/318/
[FAILURE] http://ci.openlp.org/job/Branch-05a-Code_Analysis/455/
Stopping after failure
Code analysis failure is:
openlp/branch/openlp/core/common/historycombobox.py
Not part of this branch
--
Your team OpenLP Core is subscribed to branch lp:openlp.
=== modified file 'tests/functional/openlp_plugins/songs/test_songselect.py'
--- tests/functional/openlp_plugins/songs/test_songselect.py 2015-02-06 22:21:01 +0000
+++ tests/functional/openlp_plugins/songs/test_songselect.py 2015-02-18 22:46:24 +0000
@@ -471,7 +471,6 @@
def setUp(self):
"""
Initial setups
- :return:
"""
Registry.create()
test_song_name = 'TestSong'
@@ -484,14 +483,12 @@
def tearDown(self):
"""
Test cleanups
- :return:
"""
pass
def songselect_import_usr_file_test(self):
"""
Verify import SongSelect USR file parses file properly
- :return:
"""
# GIVEN: Text file to import and mocks
copyright = '2011 OpenLP Programmer One (Admin. by OpenLP One) | ' \
@@ -510,14 +507,13 @@
self.assertEquals(song_import.title, self.title, 'Song title should match')
self.assertEquals(song_import.ccli_number, self.ccli_number, 'CCLI Song Number should match')
self.assertEquals(song_import.authors, self.authors, 'Author(s) should match')
- self.assertEquals(song_import.copyright, self.copyright_usr, 'Copyright should match')
+ self.assertEquals(song_import.copyright, copyright, 'Copyright should match')
self.assertEquals(song_import.topics, self.topics, 'Theme(s) should match')
- self.assertEquals(song_import.verses, self.verses, 'Verses should match with test verses')
+ self.assertEquals(song_import.verses, verses, 'Verses should match with test verses')
- def songselect_import_usr_file_test(self):
+ def songselect_import_text_file_test(self):
"""
Verify import SongSelect USR file parses file properly
:return:
"""
# GIVEN: Text file to import and mocks
copyright = '© 2011 OpenLP Programmer One (Admin. by OpenLP One)'
@@ -510,14 +507,13 @@
"""
- Verify import SongSelect USR file parses file properly
- :return:
+ Verify import SongSelect TEXT file parses file properly
"""
# GIVEN: Text file to import and mocks
Follow ups